|Basic Model Interface| |Build/Test CI|

bmi-topography
==============

Fetch and cache NASA Shuttle Radar Topography Mission (SRTM) land
elevation data through a BMI.

.. |Basic Model Interface| image:: https://img.shields.io/badge/CSDMS-Basic%20Model%20Interface-green.svg
   :target: https://bmi.readthedocs.io/
.. |Build/Test CI| image:: https://github.com/csdms/bmi-topography/actions/workflows/build-test-ci.yml/badge.svg
   :target: https://github.com/csdms/bmi-topography/actions/workflows/build-test-ci.yml
